@@ -21,7 +21,7 @@ with MAD(debug=False) as mad:
     mad["srv", "mflw"] = mad.survey(sequence=mad.ps)
 
     mad.srv.write("'PS_survey_py.tfs'",
-        ["name", "kind", "s", "l", "angle", "x", "y", "z", "theta"],
+        mad.py_strs_to_mad_strs(["name", "kind", "s", "l", "angle", "x", "y", "z", "theta"]),
         )
 
     mad["mtbl", "mflw"] = mad.twiss(sequence=mad.ps, method=6, nslice=3, chrom=True)
@@ -29,12 +29,14 @@ with MAD(debug=False) as mad:
     mad.load("MAD.gphys", ["melmcol"])
     #Add element properties as columns
     mad.melmcol(mad.mtbl,
-        ["angle", "tilt", "k0l", "k1l", "k2l", "k3l", "k4l", "k5l", "k6l", "k0sl",
-         "k1sl", "k2sl", "k3sl", "k4sl", "k5sl", "k6sl", "ksl", "hkick", "vkick" ],
+        mad.py_strs_to_mad_strs(
+            ["angle", "tilt", "k0l", "k1l", "k2l", "k3l", "k4l", "k5l", "k6l", "k0sl",
+            "k1sl", "k2sl", "k3sl", "k4sl", "k5sl", "k6sl", "ksl", "hkick", "vkick" ]),
         )
 
     mad.mtbl.write("'PS_twiss_py.tfs'",
-        ["name", "kind", "s", "x", "px", "beta11", "alfa11", "beta22", "alfa22","dx",
-         "dpx", "mu1", "mu2", "l", "angle", "k0l", "k1l", "k2l", "k3l", "hkick", "vkick"],
+        mad.py_strs_to_mad_strs(
+            ["name", "kind", "s", "x", "px", "beta11", "alfa11", "beta22", "alfa22","dx",
+            "dpx", "mu1", "mu2", "l", "angle", "k0l", "k1l", "k2l", "k3l", "hkick", "vkick"]),
         )
     time.sleep(1) #So tws:write() can be performed before MAD is shutdown
