@@ -62,21 +62,33 @@ class TestObjects(unittest.TestCase):
     def test_call_obj(self):
         with MAD() as mad:
             mad.load("element", ["quadrupole", "sextupole"])
-            mad.quadrupole(knl=[0, 0.25], l = 1)
-            mad["qd"] = madReference("__last__", mad)
+            qd = mad.quadrupole(knl=[0, 0.25], l = 1)
+            sd = mad.sextupole(knl=[0, 0.25, 0.5], l = 1)
+
+            mad["qd"] = qd
             self.assertEqual(mad.qd.__name__, "qd")
             self.assertEqual(mad.qd.__parent__, None)
             self.assertEqual(mad.qd.__mad__, mad)
             self.assertEqual(mad.qd.knl, [0, 0.25])
             self.assertEqual(mad.qd.l, 1)
 
-            mad["sd"] = mad.sextupole(knl=[0, 0.25, 0.5], l = 1)
+            sdc = sd
+            mad["sd"] = sd
+            del sd
             self.assertEqual(mad.sd.__name__, "sd")
             self.assertEqual(mad.sd.__parent__, None)
             self.assertEqual(mad.sd.__mad__, mad)
             self.assertEqual(mad.sd.knl, [0, 0.25, 0.5])
             self.assertEqual(mad.sd.l, 1)
 
+            #Reference counting
+            qd = mad.quadrupole(knl=[0, 0.3], l = 1)
+            self.assertEqual(sdc.__name__, "__last__[2]")
+            self.assertEqual(qd.__name__, "__last__[3]")
+            self.assertEqual(qd.knl, [0, 0.3])
+            qd = mad.quadrupole(knl=[0, 0.25], l = 1)
+            self.assertEqual(qd.__name__, "__last__[1]") 
+
     def test_call_func(self):
         with MAD() as mad:
             mad.load("element", "quadrupole")
@@ -90,7 +102,7 @@ class TestObjects(unittest.TestCase):
             mad.qd.set_variables({"l": 2})
             self.assertEqual(mad.qd.l, 2)
     
-    def test_mult_retrn(self):
+    def test_mult_rtrn(self):
         with MAD() as mad:
             mad.send("""
             obj = MAD.object "obj" {a = 1, b = 2}
@@ -98,11 +110,11 @@ class TestObjects(unittest.TestCase):
                 obj2 = MAD.object "obj2" {a = 2, b = 3}
                 return obj, obj, obj, obj2
             end
-            __last__ = __mklast__(mult_rtrn())
+            last_rtn = __mklast__(mult_rtrn())
             lastobj = __mklast__(obj)
             notLast = {mult_rtrn()}
             """)
-            mad["o11", "o12", "o13", "o2"] = madReference("__last__", mad)
+            mad["o11", "o12", "o13", "o2"] = madReference("last_rtn", mad)
             mad["p11", "p12", "p13", "p2"] = madReference("notLast", mad)
             mad["objCpy"] = madReference("lastobj", mad) #Test single object in __mklast__
             self.assertEqual(mad.o11.a, 1)
@@ -151,6 +163,38 @@ class TestObjects(unittest.TestCase):
             self.assertEqual(np.sin(1), mad.math.sin(1).eval())
             self.assertEqual(np.cos(0.5), mad.math.cos(0.5).eval())
 
+            # temp vars
+            res = (((mad.matrix(3).seq().emul(2) * mad.matrix(3).seq(3) + 3) * 2 + mad.matrix(3).seq(2)) - mad.matrix(3).seq(4)).eval()
+            np_mat = np.arange(9).reshape((3,3)) + 1
+            exp = (((np.matmul((np_mat * 2), (np_mat+3)) + 3) * 2 + (np_mat+2)) - (np_mat+4))
+            self.assertTrue(np.all(exp == res))
+
+
+    def test_args(self):
+        with MAD() as mad:
+            mad.load("MAD", ["matrix", "cmatrix"])
+            mad["m1"] = mad.matrix(3).seq()
+            mad["m2"] = mad.matrix(3).eye(2).mul(mad.m1)
+            mad["m3"] = mad.matrix(3).seq().emul(mad.m1)
+            mad["cm1"] = mad.cmatrix(3).seq(1j).map([1, 5, 9], "\mn, n -> mn - 1i")
+            self.assertTrue(np.all(mad.m2 == mad.m1 * 2))
+            self.assertTrue(np.all(mad.m3 == (mad.m1 * mad.m1)))
+            self.assertTrue(np.all(mad.cm1 == mad.m1 + 1j - np.eye(3)*1j))
+            #Add bool
+
+    def test_kwargs(self):
+        with MAD() as mad:
+            mad.load("element", "sextupole")
+            mad["m1"] = mad.MAD.matrix(3).seq()
+            sd = mad.sextupole(knl=[0, 0.25j, 1 + 1j], l = 1, alist = [1, 2, 3, 5], abool = True, opposite = False, mat = mad.m1)
+            self.assertEqual(sd.knl, [0, 0.25j, 1 + 1j])
+            self.assertEqual(sd.l, 1)
+            self.assertEqual(sd.alist, [1, 2, 3, 5])
+            self.assertEqual(sd.abool, True)
+            self.assertEqual(sd.opposite, False)
+            self.assertTrue(np.all(sd.mat == np.arange(9).reshape((3, 3)) + 1))
+
+
     def test_benchmark(self):
         with MAD() as mad:
             mad.load("element", "quadrupole")
